import React from 'react';

var splitClassName = function splitClassName(className) {
  return className.split(/\s+/g);
};

var mapAndMergeClassNames = function mapAndMergeClassNames(className, namesMap) {
  var namesArray = Array.isArray(className) ? className : [className];
  var splitNamesArr = namesArray.flatMap(function (name) {
    return splitClassName(name);
  });
  return splitNamesArr.map(function (name) {
    var _namesMap$name;

    return (_namesMap$name = namesMap[name]) != null ? _namesMap$name : name;
  }).join(' ');
};

var patchClassNamesOfChildren = function patchClassNamesOfChildren(namesMap, children) {
  return React.Children.map(children, function (child) {
    if (!React.isValidElement(child)) {
      return child;
    }

    var className = child.props.className;
    var patchedChildren = patchClassNamesOfChildren(namesMap, child.props.children);
    return React.cloneElement(child, className ? {
      className: mapAndMergeClassNames(className, namesMap)
    } : undefined, patchedChildren);
  });
};

var PatchStyles = function PatchStyles(_ref) {
  var classNames = _ref.classNames,
      children = _ref.children;

  if (!children) {
    throw new Error('ApplyStyles should always have children to apply styles too');
  }

  return React.createElement(React.Fragment, null, patchClassNamesOfChildren(classNames, children));
};

export default PatchStyles;
//# sourceMappingURL=index.js.map
